@@ -9,7 +9,7 @@ urlpatterns = patterns('',
 )
 
 urlpatterns += patterns('',
-    url(r'^datamaps/', include('core.urls')),
+    url(r'^maps/', include('core.urls')),
     url(r'^$', TemplateView.as_view(
         template_name="index.html")),
 )
\ No newline at end of file
